@@ -5,10 +5,10 @@ package Modern::Open;
 #
 # http://search.cpan.org/dist/Modern-Open/
 #
-# Copyright (c) 2014 INABA Hitoshi <ina@cpan.org>
+# Copyright (c) 2014, 2015 INABA Hitoshi <ina@cpan.org>
 ######################################################################
 
-$Modern::Open::VERSION = 0.06;
+$Modern::Open::VERSION = 0.07;
 
 use 5.00503;
 use strict;
@@ -295,7 +295,7 @@ sub INIT {
     if ($] < 5.006) {
 
         # on Strict::Perl
-        if (grep(m{\bStrict/Perl\.pm$},keys %INC)) {
+        if (exists $INC{'Strict/Perl.pm'}) {
 
             # avoid: Can't use string ("main::open") as a symbol ref while "strict refs" in use
             no strict 'refs';
@@ -378,6 +378,8 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 
 =item * L<Welcome to CP5.5.3AN|http://cp5.5.3an.barnyard.co.uk/> - cp5.5.3an.barnyard.co.uk
 
+=item * L<Strict::Perl|http://search.cpan.org/dist/Strict-Perl/> - CPAN
+
 =item * L<japerl|http://search.cpan.org/dist/japerl/> - CPAN
 
 =item * L<ina|http://search.cpan.org/~ina/> - CPAN
